pub enum ByteRange {
Bounded(Range<ChunkOffset>),
From(ChunkOffset),
Last(ChunkLength),
Until(ChunkOffset),
}Expand description
A byte range within a chunk or object.
Variants
Bounded(Range<ChunkOffset>)
The fixed length range represented by the given Range
From(ChunkOffset)
All bytes from the given offset (included) to the end of the object
Last(ChunkLength)
The last n bytes in the object
Until(ChunkOffset)
All bytes up to the last n bytes in the object
Implementations
Sourceimpl ByteRange
impl ByteRange
pub const ALL: Self
pub fn from_offset(offset: ChunkOffset) -> Self
pub fn from_offset_with_length(offset: ChunkOffset, length: ChunkOffset) -> Self
pub fn to_offset(offset: ChunkOffset) -> Self
pub fn bounded(start: ChunkOffset, end: ChunkOffset) -> Self
pub fn slice(&self, bytes: &Bytes) -> Bytes