ArrayShape

Struct ArrayShape 

pub struct ArrayShape(/* private fields */);

Implementations

Source

impl ArrayShape

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get(&self, ax: usize) -> Option<DimensionShape>

pub fn iter(&self) -> impl Iterator<Item = &DimensionShape>

pub fn num_chunks(&self) -> impl Iterator<Item = u32>

pub fn new<I>(it: I) -> Option<Self>
where I: IntoIterator<Item = (u64, u32)>,

pub fn valid_chunk_coord(&self, coord: &ChunkIndices) -> bool

Validates the provided chunk coordinates for the array.

This function checks if the provided chunk indices are valid for the array.

Arguments
  • coord - The chunk indices to validate.
Returns

An bool indicating whether the chunk coordinates are valid.

Errors

Returns false if the chunk coordinates are invalid.