pub struct TransactionLog { /* private fields */ }Implementations
Sourceimpl TransactionLog
impl TransactionLog
Sourcepub fn new_from_parts(
id: &SnapshotId,
sorted_new_groups: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator,
sorted_new_arrays: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator,
sorted_deleted_groups: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator,
sorted_deleted_arrays: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator,
sorted_updated_groups: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator,
sorted_updated_arrays: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator,
sorted_updated_chunks: impl ExactSizeIterator<Item = (NodeId, impl Iterator<Item = ChunkIndices>)> + DoubleEndedIterator,
sorted_moves: impl Iterator<Item = Move>,
) -> Self
pub fn new_from_parts( id: &SnapshotId, sorted_new_groups: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator, sorted_new_arrays: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator, sorted_deleted_groups: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator, sorted_deleted_arrays: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator, sorted_updated_groups: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator, sorted_updated_arrays: impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator, sorted_updated_chunks: impl ExactSizeIterator<Item = (NodeId, impl Iterator<Item = ChunkIndices>)> + DoubleEndedIterator, sorted_moves: impl Iterator<Item = Move>, ) -> Self
Low level method that creates a tx log from its parts Intended to be used only by library creators
pub fn from_buffer(buffer: Vec<u8>) -> IcechunkResult<Self>
pub fn new_groups( &self, ) -> impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator + '_
pub fn new_arrays( &self, ) -> impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator + '_
pub fn deleted_groups( &self, ) -> impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator + '_
pub fn deleted_arrays( &self, ) -> impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator + '_
pub fn updated_groups( &self, ) -> impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator + '_
pub fn updated_arrays( &self, ) -> impl ExactSizeIterator<Item = NodeId> + DoubleEndedIterator + '_
pub fn updated_chunks( &self, ) -> impl Iterator<Item = (NodeId, impl Iterator<Item = ChunkIndices> + '_)> + '_
pub fn moves(&self) -> impl Iterator<Item = IcechunkResult<Move>> + '_
pub fn updated_chunks_for( &self, node: &NodeId, ) -> impl Iterator<Item = ChunkIndices> + '_ + use<'_>
pub fn updated_chunks_counts( &self, ) -> impl Iterator<Item = (NodeId, u64)> + '_ + use<'_>
pub fn group_created(&self, id: &NodeId) -> bool
pub fn array_created(&self, id: &NodeId) -> bool
pub fn group_deleted(&self, id: &NodeId) -> bool
pub fn array_deleted(&self, id: &NodeId) -> bool
pub fn group_updated(&self, id: &NodeId) -> bool
pub fn array_updated(&self, id: &NodeId) -> bool
pub fn chunks_updated(&self, id: &NodeId) -> bool
pub fn bytes(&self) -> &[u8] ⓘ
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn has_moves(&self) -> bool
pub fn merge<'a, T: IntoIterator<Item = &'a TransactionLog>>( id: &SnapshotId, iter: T, ) -> IcechunkResult<Self>